@@ -132,14 +132,18 @@ CIFWrite(rootDef, f)
      */
 
     dummy.cu_def = rootDef;
-    DBCellReadArea(&dummy, &rootDef->cd_bbox);
+    if (DBCellReadArea(&dummy, &rootDef->cd_bbox, TRUE))
+    {
+	TxError("Failure to read in entire subtree of the cell.\n");
+	return (FALSE);
+    }
     DBFixMismatch();
 
     if (CIFCurStyle->cs_reducer == 0)
     {
 	TxError("The current CIF output style can only be used for writing\n");
 	TxError("Calma output.  Try picking another output style.\n");
-	return (TRUE);
+	return (FALSE);
     }
 
     /*
@@ -378,7 +382,8 @@ cifOutFunc(def, f)
 
     GEO_EXPAND(&def->cd_bbox, CIFCurStyle->cs_radius, &bigArea);
     CIFErrorDef = def;
-    CIFGen(def, def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE);
+    CIFGen(def, def, &bigArea, CIFPlanes, &DBAllTypeBits, TRUE, TRUE, FALSE,
+		(ClientData)NULL);
     if (!CIFHierWriteDisable)
 	CIFGenSubcells(def, &bigArea, CIFPlanes);
     if (!CIFArrayWriteDisable)
