@@ -881,6 +881,7 @@ cmdExpandFunc(use, windowMask)
 #define	DOLOCAL		5
 #define	DORESISTANCE	6
 #define	DOLABELCHECK	7
+#define	DOALIASES	8
 
 #define	LENCLEAR	0
 #define	LENDRIVER	1
@@ -924,6 +925,7 @@ CmdExtract(w, cmd)
 	"local			put all generated files in the current directory",
 	"resistance		estimate resistance",
 	"labelcheck		check for connections through sticky labels",
+	"aliases		output all net name aliases",
 	NULL
     };
     static char *cmdExtLength[] =
@@ -933,11 +935,15 @@ CmdExtract(w, cmd)
 	"receiver termName(s)	identify a receiving (input) terminal",
 	NULL
     };
+
+    /* These must match definitions EXT_UNIQ_* in extract/extract.h: */
+
     static char *cmdExtUniq[] =
     {
 	"all			extract matching labels as unique nodes",
 	"#			extract tagged labels as unique nodes",
 	"noports		ignore ports when making labels unique",
+	"notopports		ignore top-level ports when making labels unique",
 	NULL
     };
     static char *cmdExtCmd[] =
@@ -1144,6 +1150,7 @@ CmdExtract(w, cmd)
 		TxPrintf("%s local\n", OPTSET(EXT_DOLOCAL));
 		TxPrintf("%s resistance\n", OPTSET(EXT_DORESISTANCE));
 		TxPrintf("%s label check\n", OPTSET(EXT_DOLABELCHECK));
+		TxPrintf("%s aliases\n", OPTSET(EXT_DOALIASES));
 		return;
 #undef	OPTSET
 	    }
@@ -1173,6 +1180,7 @@ CmdExtract(w, cmd)
 		case DOLOCAL:		option = EXT_DOLOCAL; break;
 		case DORESISTANCE:	option = EXT_DORESISTANCE; break;
 		case DOLABELCHECK:	option = EXT_DOLABELCHECK; break;
+		case DOALIASES:		option = EXT_DOALIASES; break;
 	    }
 	    if (no) ExtOptions &= ~option;
 	    else ExtOptions |= option;
