@@ -1586,7 +1586,7 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
     Rect		localrect;
     int			pnum, xpos, ypos;
     char 		*xstr, *ystr;
-    bool		locvalid;
+    bool		locvalid = FALSE, usefound = TRUE;
     TileType		ttype;
 
     scx.scx_use = use;
@@ -1600,9 +1600,11 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
 	use = scx2.scx_use;
 	if (use == NULL)
 	{
-	    if (warn_not_found)
-		TxError("Couldn't find use %s\n", s);
-	    return TT_SPACE;
+	    /* Assume slash is part of the name and try to find locally */
+	    *s2 = '/';
+	    s = nodename;
+	    usefound = FALSE;
+	    goto checklocal;
 	}
 	GeoTransTrans(DBGetArrayTransform(use, scx2.scx_x, scx2.scx_y),
 	  		&use->cu_transform, &tmp);
@@ -1621,7 +1623,6 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
     /* see extract/extBasic.c for the format of the node, found */
     /* in extMakeNodeNumPrint().				*/
 
-    locvalid = FALSE;
     if ((xstr = strchr(s, '_')) != NULL)
     {
 	bool isNeg = FALSE;
@@ -1674,10 +1675,10 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
     /* coordinates that is no longer generated by magic.  It is kept	*/
     /* here for backward compatibility.					*/
 
-    if ((locvalid == FALSE) && (sscanf(s,"%d_%d_%d",&pnum,&xpos,&ypos) == 3))
+    if ((locvalid == FALSE) && (sscanf(s, "%d_%d_%d", &pnum, &xpos, &ypos) == 3))
     {
-	xpos = ((xpos & 0x1)?-1:1)*xpos/2;
-	ypos = ((ypos & 0x1)?-1:1)*ypos/2;
+	xpos = ((xpos & 0x1) ? -1 : 1) * xpos / 2;
+	ypos = ((ypos & 0x1) ? -1 : 1) * ypos / 2;
 	localrect.r_xbot = xpos;
 	localrect.r_ybot = ypos;
 	localrect.r_xtop = xpos + 1;
@@ -1685,6 +1686,8 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
 	locvalid = TRUE;
     }
 
+checklocal:
+
     if (locvalid == TRUE)
     {
 	int findTile();
@@ -1714,7 +1717,11 @@ CmdFindNetProc(nodename, use, rect, warn_not_found)
 	else
 	{
 	    if (warn_not_found)
+	    {
 		TxError("Couldn't find label %s\n", s);
+		if (!usefound)
+		    TxError("Couldn't find use referenced in hierarchical name\n");
+	    }
 	    return TT_SPACE;
 	}
     }
