@@ -1,7 +1,7 @@
 
 #ifndef	lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCextend.c,v 1.5 2010/06/24 12:37:16 tim Exp $";
-#endif	
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/drc/DRCextend.c,v 1.6 2010/09/20 21:13:22 tim Exp $";
+#endif
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -73,7 +73,51 @@ drcCheckAngles(tile, arg, cptr)
 /*
  *-------------------------------------------------------------------------
  *
- * drcCheckArea- checks to see that a collection of tiles of a given 
+ * drcCheckOffGrid- checks to see that an edge is on the specified
+ *	grid pitch.
+ *
+ * Results: none
+ *
+ * Side Effects: may cause errors to be painted.
+ *
+ *-------------------------------------------------------------------------
+ */
+
+void
+drcCheckOffGrid(edgeRect, arg, cptr)
+	Rect	*edgeRect;
+	struct drcClientData	*arg;
+	DRCCookie	*cptr;
+{
+    Rect rect;
+    int gtest;
+
+    if (cptr->drcc_dist <= 1) return;	/* No error by definition */
+
+    rect = *edgeRect;
+    GeoClip(&rect, arg->dCD_clip);
+
+    /* Expand rect to nearest pitch */
+    gtest = (rect.r_xbot / cptr->drcc_dist) * cptr->drcc_dist;
+    if (gtest < rect.r_xbot) rect.r_xbot = gtest;
+    gtest = (rect.r_xtop / cptr->drcc_dist) * cptr->drcc_dist;
+    if (gtest > rect.r_xtop) rect.r_xtop = gtest;
+    gtest = (rect.r_ybot / cptr->drcc_dist) * cptr->drcc_dist;
+    if (gtest < rect.r_ybot) rect.r_ybot = gtest;
+    gtest = (rect.r_ytop / cptr->drcc_dist) * cptr->drcc_dist;
+    if (gtest > rect.r_ytop) rect.r_ytop = gtest;
+
+    if (!GEO_RECTNULL(&rect)) {
+	(*(arg->dCD_function)) (arg->dCD_celldef, &rect,
+		 arg->dCD_cptr, arg->dCD_clientData);
+	(*(arg->dCD_errors))++;
+    }
+}
+
+/*
+ *-------------------------------------------------------------------------
+ *
+ * drcCheckArea- checks to see that a collection of tiles of a given
  *	type have more than a minimum area.
  *
  * Results: none
@@ -91,13 +135,13 @@ drcCheckArea(starttile,arg,cptr)
 
 {
     int			arealimit;
-    int			area=0;
+    long		area = 0L;
     TileTypeBitMask	*oktypes = &cptr->drcc_mask;
     Tile		*tile,*tp;
     Rect		*cliprect = arg->dCD_rect;
 
     arealimit = cptr->drcc_cdist;
-     
+
     arg->dCD_cptr = cptr;
     if (DRCstack == (Stack *) NULL)
 	DRCstack = StackNew(64);
@@ -109,7 +153,7 @@ drcCheckArea(starttile,arg,cptr)
     {
 	tile = (Tile *) STACKPOP(DRCstack);
 	if (tile->ti_client != (ClientData)DRC_PENDING) continue;
-	area += (RIGHT(tile)-LEFT(tile))*(TOP(tile)-BOTTOM(tile));
+	area += (long)(RIGHT(tile)-LEFT(tile))*(TOP(tile)-BOTTOM(tile));
 	tile->ti_client = (ClientData)DRC_PROCESSED;
 	/* are we at the clip boundary? If so, skip to the end */
 	if (RIGHT(tile) == cliprect->r_xtop ||
@@ -117,7 +161,7 @@ drcCheckArea(starttile,arg,cptr)
 	    BOTTOM(tile) == cliprect->r_ybot ||
 	    TOP(tile) == cliprect->r_ytop) goto forgetit;
 
-        if (area >= arealimit) goto forgetit;
+        if (area >= (long)arealimit) goto forgetit;
 
 	/* Top */
 	for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp))
@@ -136,7 +180,7 @@ drcCheckArea(starttile,arg,cptr)
 	    if (TTMaskHasType(oktypes, TiGetLeftType(tp))) PUSHTILE(tp);
      }
 
-     if (area < arealimit)
+     if (area < (long)arealimit)
      {
 	 Rect	rect;
 	 TiToRect(starttile,&rect);
@@ -144,10 +188,6 @@ drcCheckArea(starttile,arg,cptr)
 	 if (!GEO_RECTNULL(&rect)) {
 	     (*(arg->dCD_function)) (arg->dCD_celldef, &rect,
 		 arg->dCD_cptr, arg->dCD_clientData);
-	     /***
-	     DBWAreaChanged(arg->dCD_celldef,&rect, DBW_ALLWINDOWS, 
-						    &DBAllButSpaceBits);
-	     ***/
 	     (*(arg->dCD_errors))++;
 	 }
      }
@@ -197,7 +237,7 @@ forgetit:
      }
 }
 
-
+
 /*
  *-------------------------------------------------------------------------
  *
@@ -217,11 +257,14 @@ forgetit:
  */
 
 int
-drcCheckMaxwidth(starttile,arg,cptr)
+drcCheckMaxwidth(starttile,arg,cptr,both)
     Tile	*starttile;
     struct drcClientData	*arg;
     DRCCookie	*cptr;
+    bool both;
 {
+    int			width;
+    int			height;
     int			edgelimit;
     int			retval = 0;
     Rect		boundrect;
@@ -244,7 +287,7 @@ drcCheckMaxwidth(starttile,arg,cptr)
 	tile = (Tile *) STACKPOP(DRCstack);
 	if (tile->ti_client != (ClientData)DRC_PENDING) continue;
 	tile->ti_client = (ClientData)DRC_PROCESSED;
-	
+
 	if (boundrect.r_xbot > LEFT(tile)) boundrect.r_xbot = LEFT(tile);
 	if (boundrect.r_xtop < RIGHT(tile)) boundrect.r_xtop = RIGHT(tile);
 	if (boundrect.r_ybot > BOTTOM(tile)) boundrect.r_ybot = BOTTOM(tile);
@@ -274,8 +317,11 @@ drcCheckMaxwidth(starttile,arg,cptr)
 	    if (TTMaskHasType(oktypes, TiGetLeftType(tp))) PUSHTILE(tp);
     }
 
-    if (boundrect.r_xtop - boundrect.r_xbot > edgelimit &&
-             boundrect.r_ytop - boundrect.r_ybot > edgelimit) 
+    width = boundrect.r_xtop - boundrect.r_xbot;
+    height = boundrect.r_ytop - boundrect.r_ybot;
+
+    if ( (width > edgelimit && height > edgelimit) ||
+          ( both == TRUE && (width > edgelimit || height > edgelimit)) )
     {
 	Rect	rect;
 	TiToRect(starttile,&rect);
@@ -286,7 +332,7 @@ drcCheckMaxwidth(starttile,arg,cptr)
 	    (*(arg->dCD_errors))++;
 	    retval = 1;
 	}
-	 
+
     }
 
     /* reset the tiles */
@@ -332,13 +378,13 @@ drcCheckMaxwidth(starttile,arg,cptr)
     return retval;
 }
 
-
+
 /*
  *-------------------------------------------------------------------------
  *
- * drcCheckRectSize- 
+ * drcCheckRectSize-
  *
- *	Checks to see that a collection of tiles of given 
+ *	Checks to see that a collection of tiles of given
  *	types have the proper size (max size and also even or odd size).
  *
  * Results: none
@@ -372,10 +418,10 @@ drcCheckRectSize(starttile, arg, cptr)
      */
     arg->dCD_cptr = cptr;
     ASSERT(TTMaskHasType(oktypes, TiGetType(starttile)), "drcCheckRectSize");
-    for (t = starttile; TTMaskHasType(oktypes, TiGetType(t)); t = TR(t)) 
+    for (t = starttile; TTMaskHasType(oktypes, TiGetType(t)); t = TR(t))
 	/* loop has empty body */ ;
     errwidth = width = LEFT(t) - LEFT(starttile);
-    for (t = starttile; TTMaskHasType(oktypes, TiGetType(t)); t = RT(t)) 
+    for (t = starttile; TTMaskHasType(oktypes, TiGetType(t)); t = RT(t))
 	/* loop has empty body */ ;
     errheight = height = BOTTOM(t) - BOTTOM(starttile);
     ASSERT(width > 0 && height > 0, "drcCheckRectSize");
@@ -399,7 +445,7 @@ drcCheckRectSize(starttile, arg, cptr)
 		arg->dCD_cptr, arg->dCD_clientData);
 	    (*(arg->dCD_errors))++;
 	}
-	
+
     }
 }
 
@@ -450,17 +496,19 @@ drcCanonicalMaxwidth(starttile, dir, arg, cptr)
     static MaxRectsData *mrd = (MaxRectsData *)NULL;
     Rect	    *boundrect, boundorig;
 
-    /* Generate an initial array size of 4 for rlist and swap. */
+    /* Generate an initial array size of 8 for rlist and swap. */
     if (mrd == (MaxRectsData *)NULL)
     {
 	mrd = (MaxRectsData *)mallocMagic(sizeof(MaxRectsData));
-	mrd->rlist = (Rect *)mallocMagic(4 * sizeof(Rect));
-	mrd->swap = (Rect *)mallocMagic(4 * sizeof(Rect));
+	mrd->rlist = (Rect *)mallocMagic(8 * sizeof(Rect));
+	mrd->swap = (Rect *)mallocMagic(8 * sizeof(Rect));
 	mrd->listdepth = 8;
     }
+    if (starttile == NULL) return mrd;
+
     boundrect = &(mrd->rlist[0]);
     mrd->match = CLIENTDEFAULT;
-     
+
     edgelimit = cptr->drcc_dist;
     arg->dCD_cptr = cptr;
 
