@@ -54,7 +54,6 @@ int simmergeVisit();
 
 /* Options specific to ext2sim */
 #ifdef EXT2SIM_AUTO
-bool esDoExtResis = FALSE;
 bool esDevNodesOnly = FALSE;
 bool esNoAttrs = FALSE;
 bool esHierAP = FALSE;
@@ -63,7 +62,6 @@ bool esMergeDevsC = FALSE;	/* merge devices of equal length & width */
 int esCapAccuracy = 1;
 
 #else
-extern bool esDoExtResis;
 extern bool esDevNodesOnly;
 extern bool esNoAttrs;
 extern bool esHierAP;
@@ -72,6 +70,7 @@ extern bool esMergeDevsC;
 extern int esCapAccuracy;
 #endif
 
+bool esDoSimExtResis = FALSE;
 bool esNoAlias = TRUE;
 bool esNoLabel = TRUE;
 char simesDefaultOut[FNSIZE];
@@ -323,15 +322,15 @@ CmdExtToSim(w, cmd)
 	case EXTTOSIM_EXTRESIST:
 	    if (cmd->tx_argc == 2)
 	    {
-		Tcl_SetResult(magicinterp, (esDoExtResis) ? "on" : "off", NULL);
+		Tcl_SetResult(magicinterp, (esDoSimExtResis) ? "on" : "off", NULL);
 		return;
 	    }
 	    else if (cmd->tx_argc != 3)
 		goto usage;
 	    idx = Lookup(cmd->tx_argv[2], yesno);
 	    if (idx < 0) goto usage;
-	    else if (idx < 3) esDoExtResis = TRUE;
-	    else esDoExtResis = FALSE;
+	    else if (idx < 3) esDoSimExtResis = TRUE;
+	    else esDoSimExtResis = FALSE;
 	    break;
 	case EXTTOSIM_ALIAS:
 	    if (cmd->tx_argc == 2)
@@ -446,7 +445,7 @@ CmdExtToSim(w, cmd)
 	case EXTTOSIM_DEFAULT:
 	    LocCapThreshold = 2;
 	    LocResistThreshold = 10;
-	    EFTrimFlags = 0;
+	    EFOutputFlags = 0;
 	    EFScale = 0.0;
 	    if (EFArgTech)
 	    {
@@ -522,13 +521,13 @@ runexttosim:
 
     if (simesOutName == simesDefaultOut)
 	(void) sprintf(simesDefaultOut, "%s%s.sim", inName,
-		((esDoExtResis) ? ".ext" : ""));
+		((esDoSimExtResis) ? ".ext" : ""));
     if (esAliasName == esDefaultAlias)
 	(void) sprintf(esDefaultAlias, "%s%s.al", inName,
-		((esDoExtResis) ? ".ext" : ""));
+		((esDoSimExtResis) ? ".ext" : ""));
     if (esLabelName == esDefaultLabel)
 	(void) sprintf(esDefaultLabel, "%s%s.nodes", inName,
-		((esDoExtResis) ? ".ext" : ""));
+		((esDoSimExtResis) ? ".ext" : ""));
     if ((esSimF = fopen(simesOutName, "w")) == NULL)
     {
 	char *tclres = Tcl_Alloc(128);
@@ -557,7 +556,7 @@ runexttosim:
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, FALSE, esDoExtResis, FALSE) == FALSE)
+    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE) == FALSE)
     {
 	EFDone();
 	return /* TCL_ERROR */;
@@ -734,7 +733,7 @@ main(argc, argv)
     }
 
     /* Read the hierarchical description of the input circuit */
-    if (EFReadFile(inName, FALSE, esDoExtResis, FALSE) == FALSE)
+    if (EFReadFile(inName, FALSE, esDoSimExtResis, FALSE) == FALSE)
     {
 	exit(1);
     }
@@ -1307,8 +1306,8 @@ FILE *outf;
     suf = EFHNToStr(suffix);
     if (fetInfo[type].defSubs && strcasecmp(suf,fetInfo[type].defSubs) == 0) {
     	l = strlen(suf) - 1;
-	if (  ( EFTrimFlags & EF_TRIMGLOB ) && suf[l] =='!' ||
-	      ( EFTrimFlags & EF_TRIMLOCAL ) && suf[l] == '#'  )
+	if (  ( EFOutputFlags & EF_TRIMGLOB ) && suf[l] =='!' ||
+	      ( EFOutputFlags & EF_TRIMLOCAL ) && suf[l] == '#'  )
 	      suf[l] = '\0' ;
 	if ( esFormat == SU )
 		fprintf(outf, "S_");
@@ -1604,19 +1603,32 @@ int simnodeVisit(node, res, cap)
 	putc('\n', esSimF);
     }
 
-    if (esAliasF)
+    /* Write aliases.  If the "ext2sim alias on" option was issued, then
+     * write to the alias file only (<name>.al).  Otherwise write to the
+     * <name>.sim file.
+     */
+    isGlob = EFHNIsGlob(hierName);
+    for (nn = node->efnode_name->efnn_next; nn; nn = nn->efnn_next)
     {
-	isGlob = EFHNIsGlob(hierName);
-	for (nn = node->efnode_name->efnn_next; nn; nn = nn->efnn_next)
+	if (isGlob && EFHNIsGlob(nn->efnn_hier))
+	    continue;
+
+	if (esAliasF)
 	{
-	    if (isGlob && EFHNIsGlob(nn->efnn_hier))
-		continue;
 	    fprintf(esAliasF, "= ");
 	    EFHNOut(hierName, esAliasF);
 	    fprintf(esAliasF, " ");
 	    EFHNOut(nn->efnn_hier, esAliasF);
 	    fprintf(esAliasF, "\n");
 	}
+	else
+	{
+	    fprintf(esSimF, "= ");
+	    EFHNOut(hierName, esSimF);
+	    fprintf(esSimF, " ");
+	    EFHNOut(nn->efnn_hier, esSimF);
+	    fprintf(esSimF, "\n");
+	}
     }
 
     if (esLabF)
