@@ -431,6 +431,11 @@ ExtGetDevInfo(idx, devnameptr, devtypeptr, s_rclassptr, d_rclassptr,
  * Results:
  *	Tile type that represents the device "devname" in the magic database.
  *
+ * Notes:
+ *	It is possible for the extract section to define multiple tile types
+ *	that produce the same extracted device name, so the returned TileType
+ *	is not guaranteed to be unique to the device name.
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -920,8 +925,19 @@ ExtLoadStyle(stylename)
     /* no other tech client sections depend on the extract section.	*/
 
     invext = TechSectionGetMask("extract", NULL);
+
+    /* If microns are used as units, then the TechLoad needs to convert	*/
+    /* units based on *unscaled* dimensions.  Since it gets the scale	*/
+    /* factor from CIFGetOutputScale(), the CIF units need to be	*/
+    /* unscaled.  This is cumbersome but ensures that the right units	*/
+    /* are obtained.							*/
+    CIFTechOutputScale(DBLambda[1], DBLambda[0]);
+
     TechLoad(NULL, invext);
 
+    /* Put the CIF output scale units back to what they were */
+    CIFTechOutputScale(DBLambda[0], DBLambda[1]);
+
     /* extTechFinalStyle(ExtCurStyle); */  /* Taken care of by TechLoad() */
     ExtTechScale(DBLambda[0], DBLambda[1]);
 }
