@@ -92,6 +92,11 @@ CmdLef(w, cmd)
 					 * other than pin area surrounding labels,
 					 * with the indicated setback distance.
 					 */
+    int lefPinOnly = -1;		/* If >= 0, make pins only where labels
+					 * are defined, not the whole net.  Values
+					 * > 0 limit how far pins can extend into
+					 * the interior of the cell.
+					 */
     bool lefTopLayer = FALSE;		/* If TRUE, only output the topmost
 					 * layer used by a pin, and make
 					 * all layers below it obstructions.
@@ -113,7 +118,7 @@ CmdLef(w, cmd)
     {
 	"read [filename]		read a LEF file filename[.lef]\n"
 	"    read [filename] -import	read a LEF file; import cells from .mag files\n"
-	"    read [filename] -annotate	read a LEF file for cell annotation only."
+	"    read [filename] -annotate	read a LEF file for cell annotation only.",
 	"write [filename] [-tech]	write LEF for current cell\n"
 	"    write [filename] -hide	hide all details other than ports\n"
 	"    write [filename] -hide <d>	hide details in area set back distance <d>",
@@ -129,7 +134,7 @@ CmdLef(w, cmd)
     static char *cmdDefOption[] =
     {
 	"read [filename]		read a DEF file filename[.def]",
-	"write [cell] [-allspecial]	write DEF for current or indicated cell\n",
+	"write [cell] [-allspecial]	write DEF for current or indicated cell\n"
 	"write -labels			label every net in NETS with the net name",
 	"writeall			(use \"flatten -nosubckt\" + \"def"
 					" write\" instead)",
@@ -234,6 +239,17 @@ CmdLef(w, cmd)
 				i++;
 			    }
 			}
+			else if (!strncmp(cmd->tx_argv[i], "-pinonly", 8))
+			{
+			    lefPinOnly = 0;
+			    if ((i < (cmd->tx_argc - 1)) &&
+				    StrIsNumeric(cmd->tx_argv[i + 1]))
+			    {
+				lefPinOnly = cmdParseCoord(w, cmd->tx_argv[i + 1],
+					    FALSE, TRUE);
+				i++;
+			    }
+			}
 			else if (!strncmp(cmd->tx_argv[i], "-toplayer", 9))
 			    lefTopLayer = TRUE;
 			else if (!strncmp(cmd->tx_argv[i], "-nomaster", 9))
@@ -244,8 +260,8 @@ CmdLef(w, cmd)
 		    }
 		    else goto wrongNumArgs;
 		}
-		LefWriteAll(selectedUse, lefTopCell, lefTech, lefHide, lefTopLayer,
-			    lefDoMaster, recurse);
+		LefWriteAll(selectedUse, lefTopCell, lefTech, lefHide, lefPinOnly,
+			    lefTopLayer, lefDoMaster, recurse);
 	    }
 	    break;
 	case LEF_WRITE:
@@ -286,6 +302,23 @@ CmdLef(w, cmd)
 			else
 			    TxPrintf("The \"-hide\" option is only for lef write\n");
 		    }
+		    else if (!strncmp(cmd->tx_argv[i], "-pinonly", 8))
+		    {
+			if (is_lef)
+			{
+			    lefPinOnly = 0;
+			    if ((i < (cmd->tx_argc - 1)) &&
+				    StrIsNumeric(cmd->tx_argv[i + 1]))
+			    {
+				lefPinOnly = cmdParseCoord(w, cmd->tx_argv[i + 1],
+					    FALSE, TRUE);
+				cargs--;
+				i++;
+			    }
+			}
+			else
+			    TxPrintf("The \"-pinonly\" option is only for lef write\n");
+		    }
 		    else if (!strncmp(cmd->tx_argv[i], "-toplayer", 9))
 		    {
 			if (is_lef)
@@ -339,7 +372,8 @@ CmdLef(w, cmd)
 		DefWriteCell(selectedUse->cu_def, namep, allSpecial, units);
 	    else
 		LefWriteCell(selectedUse->cu_def, namep, selectedUse->cu_def
-			== EditRootDef, lefTech, lefHide, lefTopLayer, lefDoMaster);
+			== EditRootDef, lefTech, lefHide, lefPinOnly,
+			lefTopLayer, lefDoMaster);
 	    break;
 	case LEF_HELP:
 wrongNumArgs:
