@@ -43,6 +43,8 @@ extern Tile		*FindStartTile();
 extern int		ResEachTile();
 extern int		ResLaplaceTile();
 extern ResSimNode	*ResInitializeNode();
+TileTypeBitMask		ResSDTypesBitMask;
+TileTypeBitMask		ResSubTypesBitMask;
 
 extern HashTable	ResNodeTable;
 
@@ -139,43 +141,33 @@ ResGetReCell()
  */
 void
 ResDissolveContacts(contacts)
-	ResContactPoint *contacts;
+    ResContactPoint *contacts;
 {
     TileType t, oldtype;
     Tile *tp;
     TileTypeBitMask residues;
 
     for (; contacts != (ResContactPoint *) NULL; contacts = contacts->cp_nextcontact)
-
     {
         oldtype=contacts->cp_type;
+
 #ifdef PARANOID
 	if (oldtype == TT_SPACE)
-	{
 	    TxError("Error in Contact Dissolving for %s \n",ResCurrentNode);
-	}
 #endif
-
 	DBFullResidueMask(oldtype, &residues);
 
 	DBErase(ResUse->cu_def, &(contacts->cp_rect), oldtype);
 	for (t = TT_TECHDEPBASE; t < DBNumTypes; t++)
-	{
 	    if (TTMaskHasType(&residues, t))
-	    {
-		if (TTMaskHasType(&ExtCurStyle->exts_deviceMask, t))
-		    continue;
 		DBPaint(ResUse->cu_def, &(contacts->cp_rect), t);
-	    }
-	}
 
 	tp = ResDef->cd_planes[DBPlane(contacts->cp_type)]->pl_hint;
 	GOTOPOINT(tp, &(contacts->cp_rect.r_ll));
+
 #ifdef PARANOID
 	if (TiGetTypeExact(tp) == contacts->cp_type)
-	{
 	    TxError("Error in Contact Preprocess Routines\n");
-	}
 #endif
     }
 }
@@ -209,10 +201,15 @@ ResMakePortBreakpoints(def)
     HashStartSearch(&hs);
     while((entry = HashNext(&ResNodeTable,&hs)) != NULL)
     {
-	node=(ResSimNode *) HashGetValue(entry);
+	node = (ResSimNode *)HashGetValue(entry);
 	if (node->status & PORTNODE)
 	{
-	    plane = def->cd_planes[DBPlane(node->rs_ttype)];
+	    if (node->rs_ttype <= 0)
+	    {
+		TxError("Warning:  Label \"%s\" is unconnected.\n", node->name);
+		continue;
+	    }
+
 	    rect  = &(node->rs_bbox);
 
 	    /* Beware of zero-area ports */
@@ -227,7 +224,31 @@ ResMakePortBreakpoints(def)
 		rect->r_ytop++;
 	    }
 
-	    TTMaskSetOnlyType(&mask, node->rs_ttype);
+
+	    /* If label is on a contact, the contact has been dissolved. */
+	    /* Assume that the uppermost residue is the port.  This may	 */
+	    /* not necessarily be the case.  Could do a boundary scan on */
+	    /* each residue plane to see which side of the contact is	 */
+	    /* the internal connection in the def. . .			 */
+
+	    if (DBIsContact(node->rs_ttype))
+	    {
+		TileType type;
+
+		DBFullResidueMask(node->rs_ttype, &mask);
+		for (type = DBNumUserLayers - 1; type >= TT_TECHDEPBASE; type--)
+		    if (TTMaskHasType(&mask, type))
+		    {
+			plane = def->cd_planes[DBPlane(type)];
+			break;
+		    }
+	    }
+	    else
+	    {
+		TTMaskSetOnlyType(&mask, node->rs_ttype);
+		plane = def->cd_planes[DBPlane(node->rs_ttype)];
+	    }
+
 	    (void) DBSrPaintArea((Tile *) NULL, plane, rect, &mask,
 			ResAddBreakpointFunc, (ClientData)node);
 	}
@@ -269,10 +290,32 @@ ResMakeLabelBreakpoints(def)
         node->rs_ttype = slab->lab_type;
         node->type = slab->lab_type;
 
-	plane = def->cd_planes[DBPlane(slab->lab_type)];
-	rect  = &(node->rs_bbox);
+	rect = &(node->rs_bbox);
+
+	/* If label is on a contact, the contact has been dissolved.	*/
+	/* Assume that the uppermost residue is the port.  This may	*/
+	/* not necessarily be the case.  Could do a boundary scan on	*/
+	/* each residue plane to see which side of the contact is	*/
+	/* the internal connection in the def. . .			*/
+
+	if (DBIsContact(slab->lab_type))
+	{
+	    TileType type;
+
+	    DBFullResidueMask(slab->lab_type, &mask);
+	    for (type = DBNumUserLayers - 1; type >= TT_TECHDEPBASE; type--)
+		if (TTMaskHasType(&mask, type))
+		{
+		    plane = def->cd_planes[DBPlane(type)];
+		    break;
+		}
+	}
+	else
+	{
+		TTMaskSetOnlyType(&mask, slab->lab_type);
+		plane = def->cd_planes[DBPlane(slab->lab_type)];
+	}
 
-	TTMaskSetOnlyType(&mask, slab->lab_type);
 	(void) DBSrPaintArea((Tile *) NULL, plane, rect, &mask,
 			ResAddBreakpointFunc, (ClientData)node);
 
@@ -332,6 +375,21 @@ ResFindNewContactTiles(contacts)
     for (; contacts != (ResContactPoint *) NULL; contacts = contacts->cp_nextcontact)
     {
 	DBFullResidueMask(contacts->cp_type, &mask);
+
+	/* Watch for types that connect to the substrate plane or well;	*/
+	/* e.g., psubstratepdiff connects to nwell but not through a	*/
+	/* contact.							*/
+
+	if (ExtCurStyle->exts_globSubstratePlane != -1)
+	{
+	    TileTypeBitMask cMask;
+	    TTMaskAndMask3(&cMask, &DBConnectTbl[contacts->cp_type],
+		&DBPlaneTypes[ExtCurStyle->exts_globSubstratePlane]);
+
+	    if (!TTMaskIsZero(&cMask))
+		TTMaskSetMask(&mask, &cMask);
+	}
+	
      	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
 	{
 	    tile = ResDef->cd_planes[pNum]->pl_hint;
@@ -488,7 +546,7 @@ ResProcessTiles(goodies, origin)
 		    if ((j->tj_status & RES_TILE_DONE) == 0)
 		    {
 			resCurrentNode = resptr2;
-			merged |= (*tilefunc)(tile,(Point *)NULL);
+			merged |= (*tilefunc)(tile, (Point *)NULL);
 		    }
 		    if (merged & ORIGIN) break;
 		}
@@ -499,9 +557,9 @@ ResProcessTiles(goodies, origin)
 
 	/* Next, Process all contacts. */
 
-	for (workingc = resptr2->rn_ce;workingc != NULL;workingc = workingc->ce_nextc)
+	for (workingc = resptr2->rn_ce; workingc != NULL; workingc = workingc->ce_nextc)
 	{
-	    ResContactPoint	*cp = workingc->ce_thisc;
+	    ResContactPoint *cp = workingc->ce_thisc;
 
 	    if (merged & ORIGIN) break;
 	    if (cp->cp_status == FALSE)
@@ -621,7 +679,7 @@ ResCalcPerimOverlap(tile, dev)
 	if TTMaskHasType(omask, TiGetType(tp))
 	      overlap += MIN(RIGHT(tile), RIGHT(tp)) - MAX(LEFT(tile), LEFT(tp));
     }
-    dev->overlap = overlap;
+    dev->overlap += overlap;
 }
 /*
  *-------------------------------------------------------------------------
@@ -629,7 +687,7 @@ ResCalcPerimOverlap(tile, dev)
  * resMakeDevFunc --
  *
  *  Callback function from ResExtractNet.  For each device in a node's
- *  device list pulled from the .sim file, find the tile corresponding
+ *  device list pulled from the .sim file, find the tile(s) corresponding
  *  to the device in the source tree, and fill out the complete device
  *  record (namely the full device area).
  *
@@ -646,15 +704,159 @@ resMakeDevFunc(tile, cx)
 {
     ResDevTile	*thisDev = (ResDevTile *)cx->tc_filter->tf_arg;
     Rect	devArea;
+    TileType	ttype;
 
     TiToRect(tile, &devArea);
     GeoTransRect(&cx->tc_scx->scx_trans, &devArea, &thisDev->area);
-    ResCalcPerimOverlap(tile, thisDev);
+
+    if (IsSplit(tile))
+	ttype = (SplitSide(tile)) ? SplitRightType(tile) : SplitLeftType(tile);
+    else
+	ttype = TiGetType(tile);
+
+    /* If more than one tile type extracts to the same device, then */
+    /* the device type may be different from what was recorded when */
+    /* the sim file was read.  Restricted to the plane of the	    */
+    /* original type to avoid conflict with completely different    */
+    /* devices (like transistors vs. MiM caps).			    */
+
+    if (ttype != thisDev->type)
+    {
+	if (DBPlane(ttype) != DBPlane(thisDev->type))
+	    return 0;	/* Completely different device? */
+	thisDev->type = ttype;
+    }
+
+    return 1;
+}
+
+/*
+ *-------------------------------------------------------------------------
+ *
+ * resExpandDevFunc --
+ *
+ *	Do a boundary search on the first tile found in the search context
+ *	path belonging to a device, including all tiles that belong to the
+ *	device.  For each compatible tile found, paint the device tile
+ *	type into ResUse and calculate the overlap.
+ *
+ * Returns:
+ *	1 to stop the search (only the first tile of a device needs to be
+ *	found).
+ *
+ * Side effects:
+ *	Paints into ResUse and recalculates values of thisDev.
+ *-------------------------------------------------------------------------
+ */
+
+#define DEV_PROCESSED 1
+
+int
+resExpandDevFunc(tile, cx)
+    Tile	*tile;
+    TreeContext *cx;
+{
+    ResDevTile	    *thisDev = (ResDevTile *)cx->tc_filter->tf_arg;
+    static Stack    *devExtentsStack = NULL;
+    static Stack    *devResetStack = NULL;
+    TileTypeBitMask *rMask;
+    Tile *tp, *tp2;
+    TileType	ttype;
+    int pNum;
+    Rect area;
+
+    pNum = DBPlane(thisDev->type);
+    if (devExtentsStack == NULL)
+	devExtentsStack = StackNew(8);
+    if (devResetStack == NULL)
+	devResetStack = StackNew(8);
+
+    tile->ti_client = (ClientData)DEV_PROCESSED;
+    STACKPUSH((ClientData)tile, devExtentsStack);
+
+    while (!StackEmpty(devExtentsStack))
+    {
+	tp = (Tile *) STACKPOP(devExtentsStack);
+	STACKPUSH((ClientData)tp, devResetStack);
+	TiToRect(tp, &area);
+
+	/* Paint type thisDev->type into ResUse over area of tile "tp" */
+	DBNMPaintPlane(ResUse->cu_def->cd_planes[pNum], TiGetTypeExact(tp),
+		&area, DBStdPaintTbl(thisDev->type, pNum), (PaintUndoInfo *)NULL);
+
+	/* Add source/drain perimeter overlap to the device for this tile */
+	ResCalcPerimOverlap(tp, thisDev);
+
+	/* Search boundary of the device tile for more tiles belonging  */
+	/* to the device.  If contacts are found, replace them with the */
+	/* device type.							*/
+
+	/* top */
+	for (tp2 = RT(tp); RIGHT(tp2) > LEFT(tp); tp2 = BL(tp2))
+	{
+	    if (tp2->ti_client == (ClientData)DEV_PROCESSED) continue;
+	    ttype = TiGetBottomType(tp2);
+	    if ((ttype == thisDev->type) || (DBIsContact(ttype)
+		&& TTMaskHasType(DBResidueMask(ttype), thisDev->type)))
+	    {
+		tp2->ti_client = (ClientData)DEV_PROCESSED;
+		STACKPUSH((ClientData)tp2, devExtentsStack);
+	    }
+	}
+
+	/* bottom */
+	for (tp2 = LB(tp); LEFT(tp2) < RIGHT(tp); tp2 = TR(tp2))
+	{
+	    if (tp2->ti_client == (ClientData)DEV_PROCESSED) continue;
+	    ttype = TiGetTopType(tp2);
+	    if ((ttype == thisDev->type) || (DBIsContact(ttype)
+		&& TTMaskHasType(DBResidueMask(ttype), thisDev->type)))
+	    {
+		tp2->ti_client = (ClientData)DEV_PROCESSED;
+		STACKPUSH((ClientData)tp2, devExtentsStack);
+	    }
+	}
+
+	/* right */
+	for (tp2 = TR(tp); TOP(tp2) > BOTTOM(tp); tp2 = LB(tp2))
+	{
+	    if (tp2->ti_client == (ClientData)DEV_PROCESSED) continue;
+	    ttype = TiGetLeftType(tp2);
+	    if ((ttype == thisDev->type) || (DBIsContact(ttype)
+		&& TTMaskHasType(DBResidueMask(ttype), thisDev->type)))
+	    {
+		tp2->ti_client = (ClientData)DEV_PROCESSED;
+		STACKPUSH((ClientData)tp2, devExtentsStack);
+	    }
+	}
+
+	/* left */
+	for (tp2 = BL(tp); BOTTOM(tp2) < TOP(tp); tp2 = RT(tp2))
+	{
+	    if (tp2->ti_client == (ClientData)DEV_PROCESSED) continue;
+	    ttype = TiGetRightType(tp2);
+	    if ((ttype == thisDev->type) || (DBIsContact(ttype)
+		&& TTMaskHasType(DBResidueMask(ttype), thisDev->type)))
+	    {
+		tp2->ti_client = (ClientData)DEV_PROCESSED;
+		STACKPUSH((ClientData)tp2, devExtentsStack);
+	    }
+	}
+    }
+
+    /* Reset the device tile client records */
+    while (!StackEmpty(devResetStack))
+    {
+	tp = (Tile *) STACKPOP(devResetStack);
+	tp->ti_client = (ClientData)CLIENTDEFAULT;
+    }
+
+    /* Return 1 to stop the search;  we only need to run this from  */
+    /* the first device tile.					    */
 
     return 1;
 }
 
- 
 /*
  *-------------------------------------------------------------------------
  *
@@ -676,14 +878,16 @@ ResExtractNet(node, goodies, cellname)
     char		*cellname;
 {
     SearchContext 	scx;
-    int			pNum;
     TileTypeBitMask	FirstTileMask;
+    TileTypeBitMask	tMask;
     Point		startpoint;
     static int		first = 1;
     ResDevTile		*DevTiles, *thisDev;
     ResFixPoint		*fix;
     devPtr		*tptr;
+    int			pNum;
     int			resMakeDevFunc();
+    int			resExpandDevFunc();
 
     /* Make sure all global network variables are reset */
 
@@ -759,28 +963,60 @@ ResExtractNet(node, goodies, cellname)
     DBTreeCopyConnect(&scx, &FirstTileMask, 0, ResCopyMask, &TiPlaneRect,
 					SEL_DO_LABELS, ResUse);
 
+    TTMaskZero(&ResSDTypesBitMask);
+    TTMaskZero(&ResSubTypesBitMask);
+
     /* Add devices to ResUse from list in node */
     DevTiles = NULL;
     for (tptr = node->firstDev; tptr; tptr = tptr->nextDev)
     {
-	TileTypeBitMask devMask;
+	int result;
+	int i;
+	ExtDevice *devptr;
 
-	TTMaskSetOnlyType(&devMask, tptr->thisDev->rs_ttype);
 	thisDev = (ResDevTile *)mallocMagic(sizeof(ResDevTile));
 	thisDev->devptr = tptr->thisDev->rs_devptr;
 	thisDev->type = tptr->thisDev->rs_ttype;
+	thisDev->overlap = 0;
 	scx.scx_area.r_ll.p_x = tptr->thisDev->location.p_x;
 	scx.scx_area.r_ll.p_y = tptr->thisDev->location.p_y;
 	scx.scx_area.r_xtop = scx.scx_area.r_xbot + 1;
 	scx.scx_area.r_ytop = scx.scx_area.r_ybot + 1;
-	DBTreeSrTiles(&scx, &devMask, 0, resMakeDevFunc, (ClientData)thisDev);
+	result = DBTreeSrTiles(&scx, &DBAllButSpaceAndDRCBits, 0,
+		    resMakeDevFunc, (ClientData)thisDev);
+	if (result == 0)
+	{
+	    freeMagic(thisDev);
+	    TxError("No device of type %s found at location %d,%d\n",
+		    DBTypeLongNameTbl[thisDev->type],
+		    tptr->thisDev->location.p_x,
+		    tptr->thisDev->location.p_y);
+	    continue;
+	}
 	thisDev->nextDev = DevTiles;
 	DevTiles = thisDev;
 
-	/* Paint the type into ResUse */
-	pNum = DBPlane(thisDev->type);
-	DBPaintPlane(ResUse->cu_def->cd_planes[pNum], &thisDev->area,
-		DBStdPaintTbl(thisDev->type, pNum), (PaintUndoInfo *)NULL);
+	/* Paint the entire device into ResUse */
+	TTMaskSetOnlyType(&tMask, thisDev->type);
+	DBTreeSrTiles(&scx, &tMask, 0, resExpandDevFunc, (ClientData)thisDev);
+
+	/* If the device has source/drain types in a different plane than   */
+	/* the device identifier type, then add the source/drain types to   */
+	/* the mask ResSDTypesBitMask.					    */
+
+	for (devptr = ExtCurStyle->exts_device[thisDev->type]; devptr;
+		    devptr = devptr->exts_next)
+	    for (i = 0; !TTMaskIsZero(&devptr->exts_deviceSDTypes[i]); i++)
+		TTMaskSetMask(&ResSDTypesBitMask, &devptr->exts_deviceSDTypes[i]);
+
+	/* Add the substrate types to the mask ResSubTypesBitMask	    */
+
+	for (devptr = ExtCurStyle->exts_device[thisDev->type]; devptr;
+		    devptr = devptr->exts_next)
+	    TTMaskSetMask(&ResSubTypesBitMask, &devptr->exts_deviceSubstrateTypes);
+
+	/* TT_SPACE should be removed from ResSubTypesBitMask */
+	TTMaskClearType(&ResSubTypesBitMask, TT_SPACE);
     }
     DBReComputeBbox(ResUse->cu_def);
 
@@ -1095,7 +1331,8 @@ FindStartTile(goodies, SourcePoint)
  *
  * ResGetDevice -- Once the net is extracted, we still have to equate
  *	the sim file devices with the layout devices. ResGetDevice
- *	looks for a device at the given location.
+ *	looks for a device at the given location.  "type" is also
+ *	specified to that the right plane will be searched.
  *
  * Results: returns device structure at location DevicePoint, if it
  *	exists.
@@ -1106,9 +1343,9 @@ FindStartTile(goodies, SourcePoint)
  */
 
 resDevice *
-ResGetDevice(pt)
+ResGetDevice(pt, type)
     Point	*pt;
-
+    TileType	type;
 {
     Point   workingPoint;
     Tile    *tile;
@@ -1117,26 +1354,21 @@ ResGetDevice(pt)
     workingPoint.p_x = (*pt).p_x;
     workingPoint.p_y = (*pt).p_y;
 
-    for (pnum = PL_TECHDEPBASE; pnum < DBNumPlanes; pnum++)
+    pnum = DBPlane(type);
+
+    /* Start at hint tile for device plane */
+
+    tile = ResUse->cu_def->cd_planes[pnum]->pl_hint;
+    GOTOPOINT(tile, &workingPoint);
+
+    if (IsSplit(tile))
     {
-     	if (TTMaskIntersect(&ExtCurStyle->exts_deviceMask, &DBPlaneTypes[pnum]) == 0)
-	    continue;
-
-	/* Start at hint tile for device plane */
-
-	tile = ResUse->cu_def->cd_planes[pnum]->pl_hint;
-	GOTOPOINT(tile, &workingPoint);
-
-	if (IsSplit(tile))
-	{
-            if (TTMaskHasType(&ExtCurStyle->exts_deviceMask, TiGetLeftType(tile))
+        if (TTMaskHasType(&ExtCurStyle->exts_deviceMask, TiGetLeftType(tile))
               	   || TTMaskHasType(&ExtCurStyle->exts_deviceMask, TiGetRightType(tile)))
-                return (((tileJunk *)tile->ti_client)->deviceList);
-	}
-	else if (TTMaskHasType(&ExtCurStyle->exts_deviceMask, TiGetType(tile)))
-        {
             return (((tileJunk *)tile->ti_client)->deviceList);
-        }
     }
+    else if (TTMaskHasType(&ExtCurStyle->exts_deviceMask, TiGetType(tile)))
+        return (((tileJunk *)tile->ti_client)->deviceList);
+
     return NULL;
 }
