@@ -17,6 +17,7 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "tiles/tile.h"
 #include "utils/hash.h"
 #include "utils/undo.h"
+#include "utils/signals.h"
 #include "database/database.h"
 #include "utils/malloc.h"
 #include "textio/textio.h"
@@ -42,6 +43,14 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 #define Z_TO_P		1e9
 
+/* Table of nodes to ignore (manually specified) */
+
+HashTable 	ResIgnoreTable;	    /* Hash table of nodes to ignore  */
+
+/* Table of nodes to include (manually specified) */
+
+HashTable 	ResIncludeTable;    /* Hash table of nodes to include  */
+
 /* ResSimNode is a node read in from a sim file */
 
 HashTable 	ResNodeTable;   /* Hash table of sim file nodes   */
@@ -145,13 +154,13 @@ ExtResisForDef(celldef, resisdata)
 	    ResCheckSimNodes(celldef, resisdata);
 
 	if (ResOptionsFlags & ResOpt_Stat)
-	    ResPrintStats((ResGlobalParams *)NULL,"");
+	    ResPrintStats((ResGlobalParams *)NULL, "");
     }
 
     /* Clean up */
 
     HashStartSearch(&hs);
-    while((entry = HashNext(&ResNodeTable,&hs)) != NULL)
+    while((entry = HashNext(&ResNodeTable, &hs)) != NULL)
     {
 	node=(ResSimNode *) HashGetValue(entry);
 	tptr = node->firstDev;
@@ -229,6 +238,8 @@ CmdExtResis(win, cmd)
 	"lumped   [on/off]    turn on/off writing of updated lumped resistances",
 	"silent   [on/off]    turn on/off printing of net statistics",
 	"skip     mask        don't extract these types",
+	"ignore	  names	      don't extract these nets",
+	"include  names	      extract only these nets",
 	"box      type        extract the signal under the box on layer type",
 	"cell	   cellname    extract the network for the cell named cellname",
 	"blackbox [on/off]    treat subcircuits with ports as black boxes",
@@ -243,9 +254,9 @@ CmdExtResis(win, cmd)
 
 typedef enum {
 	RES_BAD=-2, RES_AMBIG, RES_TOL,
-	RES_ALL, RES_SIMP, RES_EXTOUT, RES_LUMPED,
-	RES_SILENT, RES_SKIP, RES_BOX, RES_CELL, RES_BLACKBOX,
-	RES_FASTHENRY, RES_GEOMETRY, RES_HELP,
+	RES_ALL, RES_SIMP, RES_EXTOUT, RES_LUMPED, RES_SILENT,
+	RES_SKIP, RES_IGNORE, RES_INCLUDE, RES_BOX, RES_CELL,
+	RES_BLACKBOX, RES_FASTHENRY, RES_GEOMETRY, RES_HELP,
 #ifdef LAPLACE
 	RES_LAPLACE,
 #endif
@@ -262,6 +273,8 @@ typedef enum {
 	tolerance = 1;
 	tdiTolerance = 1;
 	fhFrequency = 10e6;	/* 10 MHz default */
+	HashInit(&ResIgnoreTable, INITFLATSIZE, HT_STRINGKEYS);
+	HashInit(&ResIncludeTable, INITFLATSIZE, HT_STRINGKEYS);
 	init = 0;
     }
 
@@ -453,6 +466,56 @@ typedef enum {
 	    }
 	    return;
 
+	case RES_IGNORE:
+	    if (cmd->tx_argc > 2)
+	    {
+		if (!strcasecmp(cmd->tx_argv[2], "none"))
+		{
+		    /* Kill and reinitialize the table of ignored nets */
+		    HashKill(&ResIgnoreTable);
+		    HashInit(&ResIgnoreTable, INITFLATSIZE, HT_STRINGKEYS);
+		}
+		else
+		    HashFind(&ResIgnoreTable, cmd->tx_argv[2]);
+	    }
+	    else
+	    {
+		HashSearch hs;
+		HashEntry *entry;
+
+		/* List all net names that are being ignored */
+		HashStartSearch(&hs);
+		while((entry = HashNext(&ResIgnoreTable, &hs)) != NULL)
+		    TxPrintf("%s ", (char *)entry->h_key.h_name);
+		TxPrintf("\n");
+	    }
+	    return;
+
+	case RES_INCLUDE:
+	    if (cmd->tx_argc > 2)
+	    {
+		if (!strcasecmp(cmd->tx_argv[2], "all"))
+		{
+		    /* Kill and reinitialize the table of ignored nets */
+		    HashKill(&ResIncludeTable);
+		    HashInit(&ResIncludeTable, INITFLATSIZE, HT_STRINGKEYS);
+		}
+		else
+		    HashFind(&ResIncludeTable, cmd->tx_argv[2]);
+	    }
+	    else
+	    {
+		HashSearch hs;
+		HashEntry *entry;
+
+		/* List all net names that are being included */
+		HashStartSearch(&hs);
+		while((entry = HashNext(&ResIncludeTable, &hs)) != NULL)
+		    TxPrintf("%s ", (char *)entry->h_key.h_name);
+		TxPrintf("\n");
+	    }
+	    return;
+
 	case RES_HELP:
 	    for (i = 0; cmdExtresisCmd[i] != NULL; i++)
 		TxPrintf("%s\n", cmdExtresisCmd[i]);
@@ -559,7 +622,7 @@ typedef enum {
 
     /* Do subcircuits (if any) first */
     if (!(ResOptionsFlags & ResOpt_Blackbox))
-	(void) DBCellSrDefs(0, resSubcircuitFunc, (ClientData) &resisdata);
+	DBCellEnum(mainDef, resSubcircuitFunc, (ClientData) &resisdata);
 
     ExtResisForDef(mainDef, &resisdata);
 
@@ -586,7 +649,9 @@ typedef enum {
  *-------------------------------------------------------------------------
  *
  * resSubcircuitFunc --
- *	For each encountered cell, call the resistance extractor.
+ *	For each encountered cell, call the resistance extractor,
+ *	then recursively call resSubcircuitFunc on all children
+ *	of the cell.
  *
  * Results:
  *	Always return 0 to keep search alive.
@@ -602,12 +667,11 @@ resSubcircuitFunc(cellDef, rdata)
     CellDef *cellDef;
     ResisData *rdata;
 {
-    if ((cellDef->cd_flags & CDINTERNAL) == CDINTERNAL)
-	return 0;
-
-    if (cellDef != rdata->mainDef)
-	if (DBIsSubcircuit(cellDef))
-	    ExtResisForDef(cellDef, rdata);
+    if (DBIsSubcircuit(cellDef))
+    {
+	ExtResisForDef(cellDef, rdata);
+	DBCellEnum(cellDef, resSubcircuitFunc, (ClientData)rdata);
+    }
     return 0;
 }
 
@@ -919,28 +983,21 @@ ResCheckSimNodes(celldef, resisdata)
 
     for (node = ResOriginalNodes; node != NULL; node=node->nextnode)
     {
-	ResCurrentNode = node->name;
-	if (!(ResOptionsFlags & ResOpt_FastHenry))
+	HashEntry *he;
+
+	if (SigInterruptPending) break;
+
+	/* Ignore or include specified nodes */
+
+	if (ResIncludeTable.ht_nEntries > 0)
 	{
-	    /* Hack!!  Don't extract Vdd or GND lines */
-
-	    char *last4, *last3;
-	    last4 = node->name+strlen(node->name)-4;
-	    last3 = node->name+strlen(node->name)-3;
-
-	    if ((strncmp(last4,"Vdd!",4) == 0 ||
-	          strncmp(last4,"VDD!",4) == 0 ||
-	          strncmp(last4,"vdd!",4) == 0 ||
-	          strncmp(last4,"Gnd!",4) == 0 ||
-	          strncmp(last4,"gnd!",4) == 0 ||
-	          strncmp(last4,"GND!",4) == 0 ||
-	          strncmp(last3,"Vdd",3) == 0 ||
-	          strncmp(last3,"VDD",3) == 0 ||
-	          strncmp(last3,"vdd",3) == 0 ||
-	          strncmp(last3,"Gnd",3) == 0 ||
-	          strncmp(last3,"gnd",3) == 0 ||
-	          strncmp(last3,"GND",3) == 0) &&
-	          (node->status & FORCE) != FORCE) continue;
+	    he = HashLookOnly(&ResIncludeTable, node->name);
+	    if (he == NULL) continue;
+	}
+	else
+	{
+	    he = HashLookOnly(&ResIgnoreTable, node->name);
+	    if (he != NULL) continue;
 	}
 
 	/* Has this node been merged away or is it marked as skipped? */
@@ -949,21 +1006,25 @@ ResCheckSimNodes(celldef, resisdata)
 		((node->status & SKIP) &&
 	  	(ResOptionsFlags & ResOpt_ExtractAll) == 0))
 	    continue;
+
+	ResCurrentNode = node->name;
 	total++;
 
      	ResSortByGate(&node->firstDev);
-	/* Find largest SD device connected to node.	*/
+
+	/* Find largest SD device connected to node. */
 
 	minRes = FLT_MAX;
 	gparams.rg_devloc = (Point *) NULL;
 	gparams.rg_status = FALSE;
 	gparams.rg_nodecap = node->capacitance;
 
-	/* the following is only used if there is a drivepoint */
-	/* to identify which tile the drivepoint is on.	 */
+	/* The following is only used if there is a drivepoint */
+	/* to identify which tile the drivepoint is on.	       */
+
 	gparams.rg_ttype = node->rs_ttype;
 
-	for (ptr = node->firstDev; ptr != NULL; ptr=ptr->nextDev)
+	for (ptr = node->firstDev; ptr != NULL; ptr = ptr->nextDev)
 	{
 	    RDev	*t1;
 	    RDev	*t2;
@@ -974,8 +1035,9 @@ ResCheckSimNodes(celldef, resisdata)
 	    }
 	    else
 	    {
-	       	/* get cumulative resistance of all devices */
-		/* with same connections.			    */
+	       	/* Get cumulative resistance of all devices */
+		/* with same connections.		    */
+
 		cumRes = ptr->thisDev->resistance;
 	        t1 = ptr->thisDev;
 		for (; ptr->nextDev != NULL; ptr = ptr->nextDev)
@@ -988,7 +1050,7 @@ ResCheckSimNodes(celldef, resisdata)
 			    (t1->source != t2->drain ||
 			     t1->drain  != t2->source)) break;
 
-		    /* do parallel combination  */
+		    /* Do parallel combination  */
 		    if ((cumRes != 0.0) && (t2->resistance != 0.0))
 		    {
 			cumRes = (cumRes * t2->resistance) /
@@ -1036,7 +1098,7 @@ ResCheckSimNodes(celldef, resisdata)
 	if ((gparams.rg_devloc == NULL) && (node->status & FORCE))
 	{
     	    TxError("Node %s has force label but no drive point or "
-			"driving device\n",node->name);
+			"driving device\n", node->name);
 	}
 	if ((minRes == FLT_MAX) || (gparams.rg_devloc == NULL))
 	{
@@ -1184,7 +1246,7 @@ ResFixUpConnections(simDev, layoutDev, simNode, nodename)
 {
     static char	newname[MAXNAME], oldnodename[MAXNAME];
     int		notdecremented;
-    resNode	*gate, *source, *drain;
+    resNode	*gate, *source, *drain, *subs;
 
     /* If we aren't doing output (i.e. this is just a statistical run) */
     /* don't patch up networks.  This cuts down on memory use.		*/
@@ -1222,7 +1284,27 @@ ResFixUpConnections(simDev, layoutDev, simNode, nodename)
      	    sprintf(newname, "%s%s%d", nodename, ".t", resNodeNum++);
 	}
 	else
-	    TxError("Missing gate connection\n");
+	    TxError("Missing gate connection of device at (%d %d) on net %s\n",
+			layoutDev->rd_inside.r_xbot, layoutDev->rd_inside.r_ybot,
+			nodename);
+    }
+    if (simDev->subs == simNode)
+    {
+	if ((subs = layoutDev->rd_fet_subs) != NULL)
+	{
+	    if (subs->rn_name != NULL && notdecremented)
+	    {
+	       	resNodeNum--;
+		notdecremented = FALSE;
+	    }
+	    ResFixDevName(newname, SUBS, simDev, subs);
+	    subs->rn_name = simDev->subs->name;
+     	    sprintf(newname, "%s%s%d", nodename, ".t", resNodeNum++);
+	}
+	else
+	    TxError("Missing substrate connection of device at (%d %d) on net %s\n",
+			layoutDev->rd_inside.r_xbot, layoutDev->rd_inside.r_ybot,
+			nodename);
     }
     if (simDev->source == simNode)
     {
@@ -1245,7 +1327,9 @@ ResFixUpConnections(simDev, layoutDev, simNode, nodename)
 	       	/* one to each */
 	    }
 	    else
-	        TxError("Missing SD connection\n");
+		TxError("Missing terminal connection of device at (%d %d) on net %s\n",
+			layoutDev->rd_inside.r_xbot, layoutDev->rd_inside.r_ybot,
+			nodename);
 	}
 	else
 	{
@@ -1288,7 +1372,9 @@ ResFixUpConnections(simDev, layoutDev, simNode, nodename)
 
 	    }
 	    else
-	       	TxError("missing SD connection\n");
+	       	TxError("Missing terminal connection of device at (%d %d) on net %s\n",
+			layoutDev->rd_inside.r_xbot, layoutDev->rd_inside.r_ybot,
+			nodename);
 	}
     }
     else if (simDev->drain == simNode)
@@ -1335,7 +1421,9 @@ ResFixUpConnections(simDev, layoutDev, simNode, nodename)
 	    }
 	}
 	else
-	    TxError("missing SD connection\n");
+	    TxError("Missing terminal connection of device at (%d %d) on net %s\n",
+			layoutDev->rd_inside.r_xbot, layoutDev->rd_inside.r_ybot,
+			nodename);
     }
     else
 	resNodeNum--;
@@ -1397,6 +1485,10 @@ ResFixDevName(line, type, device, layoutnode)
 	    node->oldname = device->drain->name;
 	    device->drain = node;
 	    break;
+     	case SUBS:
+	    node->oldname = device->subs->name;
+	    device->subs = node;
+	    break;
 	default:
 	    TxError("Bad Terminal Specifier\n");
 	    break;
@@ -1660,7 +1752,7 @@ ResWriteExtFile(celldef, node, tol, rctol, nidx, eidx)
         }
         for (ptr = node->firstDev; ptr != NULL; ptr=ptr->nextDev)
         {
-	    if (layoutDev = ResGetDevice(&ptr->thisDev->location))
+	    if (layoutDev = ResGetDevice(&ptr->thisDev->location, ptr->thisDev->rs_ttype))
 	    {
 		ResFixUpConnections(ptr->thisDev, layoutDev, node, newname);
 	    }
