@@ -27,11 +27,11 @@
 #include <errno.h>
 
 #include "tcltk/tclmagic.h"
-#include "utils/main.h"   
-#include "utils/magic.h"   
+#include "utils/main.h"
+#include "utils/magic.h"
 #include "utils/geometry.h"
-#include "tiles/tile.h"  
-#include "utils/hash.h"  
+#include "tiles/tile.h"
+#include "utils/hash.h"
 #include "utils/dqueue.h"
 #include "database/database.h"
 #include "windows/windows.h"
@@ -41,7 +41,7 @@
 #include "textio/txcommands.h"
 #include "utils/signals.h"
 #include "graphics/graphics.h"
-#include "utils/malloc.h" 
+#include "utils/malloc.h"
 #include "dbwind/dbwind.h"
 
 /*
@@ -124,7 +124,7 @@ TagCallback(interp, tkpath, argc, argv)
     if (postcmd)
     {
 	/* The Tag callback should not increase the command number	*/
-	/* sequence, so save it now and restore it before returning.	*/ 
+	/* sequence, so save it now and restore it before returning.	*/
 	cmdnum = TxCommandNumber;
 
 	substcmd = (char *)mallocMagic(strlen(postcmd) + 1);
@@ -153,7 +153,7 @@ TagCallback(interp, tkpath, argc, argv)
 		    /* path has been passed in the argument.  If not, get */
 		    /* the window path if there is only one window.       */
 		    /* Otherwise, the window is unknown so we substitute  */
-		    /* a null list "{}".				  */ 
+		    /* a null list "{}".				  */
 
 		    if (tkpath == NULL)
 		    {
@@ -268,7 +268,7 @@ AddCommandTag(ClientData clientData,
 	return TCL_ERROR;
 
     entry = HashFind(&txTclTagTable, argv[1]);
- 
+
     if (entry == NULL) return TCL_ERROR;
 
     hstring = (char *)HashGetValue(entry);
@@ -302,7 +302,7 @@ static int
 _tcl_dispatch(ClientData clientData,
         Tcl_Interp *interp, int argc, char *argv[])
 {
-    int wval; 
+    int wval;
     int result, idx;
     Tcl_Obj *objv0;
     char *argv0, *tkwind;
@@ -341,7 +341,7 @@ _tcl_dispatch(ClientData clientData,
     {
 	int i;
 	Tcl_Obj **objv = (Tcl_Obj **)Tcl_Alloc(argc * sizeof(Tcl_Obj *));
-	
+
 	/* Create a Tcl_Obj array suitable for calling Tcl_EvalObjv.	*/
 	/* The first argument is changed from the magic command name to	*/
 	/* "tcl" + the command name.  This assumes that all conflicting	*/
@@ -502,7 +502,7 @@ MakeWindowCommand(char *wname, MagWindow *mw)
 /*------------------------------------------------------*/
 /* Main startup procedure				*/
 /*------------------------------------------------------*/
- 
+
 static int
 _magic_initialize(ClientData clientData,
         Tcl_Interp *interp, int argc, char *argv[])
@@ -522,7 +522,7 @@ _magic_initialize(ClientData clientData,
     // Force tkcon to send output to terminal during initialization
     else
     {
-	RuntimeFlags |= MAIN_TK_CONSOLE;
+  	RuntimeFlags |= (MAIN_TK_CONSOLE | MAIN_TK_PRINTF);
     	Tcl_Eval(consoleinterp, "rename ::puts ::unused_puts\n");
     	Tcl_Eval(consoleinterp, "rename ::tkcon_tcl_puts ::puts\n");
     }
@@ -541,6 +541,7 @@ _magic_initialize(ClientData clientData,
     // Redirect output back to the console
     if (TxTkConsole)
     {
+  	RuntimeFlags &= ~MAIN_TK_PRINTF;
     	Tcl_Eval(consoleinterp, "rename ::puts ::tkcon_tcl_puts\n");
     	Tcl_Eval(consoleinterp, "rename ::unused_puts ::puts\n");
     }
@@ -615,6 +616,100 @@ typedef struct FileState {
     int validMask;
 } FileState;
 
+/*--------------------------------------------------------------*/
+/* "Wizard" command for manipulating run-time flags.		*/
+/*--------------------------------------------------------------*/
+
+static int
+_magic_flags(ClientData clientData,
+        Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+    int index, index2;
+    bool value;
+    static char *flagOptions[] = {"debug", "recover", "silent",
+		"window", "console", "printf", (char *)NULL};
+    static char *yesNo[] = {"off", "no", "false", "0", "on", "yes",
+		"true", "1", (char *)NULL};
+
+    if ((objc != 2) && (objc != 3)) {
+	Tcl_WrongNumArgs(interp, 1, objv, "flag ?value?");
+	return TCL_ERROR;
+    }
+    if (Tcl_GetIndexFromObj(interp, objv[1], (CONST84 char **)flagOptions,
+		"option", 0, &index) != TCL_OK) {
+	return TCL_ERROR;
+    }
+    if (objc == 2) {
+	switch (index) {
+	    case 0:
+	        value = (RuntimeFlags & MAIN_DEBUG) ? TRUE : FALSE;
+		break;
+	    case 1:
+	        value = (RuntimeFlags & MAIN_RECOVER) ? TRUE : FALSE;
+		break;
+	    case 2:
+	        value = (RuntimeFlags & MAIN_SILENT) ? TRUE : FALSE;
+		break;
+	    case 3:
+	        value = (RuntimeFlags & MAIN_MAKE_WINDOW) ? TRUE : FALSE;
+		break;
+	    case 4:
+	        value = (RuntimeFlags & MAIN_TK_CONSOLE) ? TRUE : FALSE;
+		break;
+	    case 5:
+	        value = (RuntimeFlags & MAIN_TK_PRINTF) ? TRUE : FALSE;
+		break;
+	}
+	Tcl_SetObjResult(interp, Tcl_NewBooleanObj(value));
+    }
+    else {
+	if (Tcl_GetIndexFromObj(interp, objv[2], (CONST84 char **)yesNo,
+		"value", 0, &index2) != TCL_OK)
+	    return TCL_ERROR;
+
+	value = (index2 > 3) ? TRUE : FALSE;
+	switch (index) {
+	    case 0:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_DEBUG;
+		else
+		    RuntimeFlags &= ~MAIN_DEBUG;
+		break;
+	    case 1:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_RECOVER;
+		else
+		    RuntimeFlags &= ~MAIN_RECOVER;
+		break;
+	    case 2:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_SILENT;
+		else
+		    RuntimeFlags &= ~MAIN_SILENT;
+		break;
+	    case 3:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_MAKE_WINDOW;
+		else
+		    RuntimeFlags &= ~MAIN_MAKE_WINDOW;
+		break;
+	    case 4:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_TK_CONSOLE;
+		else
+		    RuntimeFlags &= ~MAIN_TK_CONSOLE;
+		break;
+	    case 5:
+		if (value == TRUE)
+		    RuntimeFlags |= MAIN_TK_PRINTF;
+		else
+		    RuntimeFlags &= ~MAIN_TK_PRINTF;
+		break;
+	}
+    }
+    return TCL_OK;
+}
+
 /*--------------------------------------------------------------*/
 /* Post-initialization:  read in the magic startup files and	*/
 /* load any initial layout.  Note that this is not done via	*/
@@ -746,7 +841,7 @@ extern char txPromptChar;
 void
 TxSetPrompt(ch)
     char ch;
-{   
+{
     Tcl_SavedResult state;
     char promptline[16];
 
@@ -757,7 +852,7 @@ TxSetPrompt(ch)
 	Tcl_EvalEx(consoleinterp, promptline, 15, 0);
 	Tcl_RestoreResult(consoleinterp, &state);
     }
-}   
+}
 
 /*--------------------------------------------------------------*/
 /* Get a line from stdin (Tcl replacement for Tx function)	*/
@@ -904,6 +999,13 @@ TxFlush()
 /*								*/
 /* 6/17/04---Routine extended to escape double-dollar-sign '$$'	*/
 /* which is used by some tools when generating via cells.	*/
+/*								*/
+/* 12/23/16---Noted that using consoleinterp simply prevents	*/
+/* the output from being redirected to another window such as	*/
+/* the command entry window.  Split off another bit TxTkOutput	*/
+/* from TxTkConsole and set it to zero by default.  The		*/
+/* original behavior can be restored using the *flags wizard	*/
+/* command (*flags printf true).				*/
 /*--------------------------------------------------------------*/
 
 int
@@ -913,7 +1015,7 @@ Tcl_printf(FILE *f, char *fmt, va_list args_in)
     static char outstr[128] = "puts -nonewline std";
     char *outptr, *bigstr = NULL, *finalstr = NULL;
     int i, nchars, result, escapes = 0, limit;
-    Tcl_Interp *printinterp = (TxTkConsole) ? consoleinterp : magicinterp;
+    Tcl_Interp *printinterp = (TxTkOutput) ? consoleinterp : magicinterp;
 
     strcpy (outstr + 19, (f == stderr) ? "err \"" : "out \"");
 
@@ -944,7 +1046,7 @@ Tcl_printf(FILE *f, char *fmt, va_list args_in)
 
     if (escapes > 0)
     {
-	/* "+ 4" required to process "$$...$$"; haven't figured out why. */ 
+	/* "+ 4" required to process "$$...$$"; haven't figured out why. */
 	finalstr = Tcl_Alloc(nchars + escapes + 26 + 4);
 	strncpy(finalstr, outptr, 24);
 	escapes = 0;
@@ -979,7 +1081,7 @@ Tcl_printf(FILE *f, char *fmt, va_list args_in)
 
     return result;
 }
-    
+
 /*--------------------------------------------------------------*/
 /* Tcl_escape() takes a string as input and produces a string	*/
 /* in which characters are escaped as necessary to make them	*/
@@ -1079,7 +1181,7 @@ TerminalInputProc(instanceData, buf, toRead, errorCodePtr)
 	if (errno != EINTR) break;
     }
     *errorCodePtr = errno;
-	
+
     return -1;
 }
 
@@ -1089,7 +1191,7 @@ int
 Tclmagic_Init(interp)
     Tcl_Interp *interp;
 {
-    char *cadroot;
+    const char *cadroot;
 
     /* Sanity check! */
     if (interp == NULL) return TCL_ERROR;
@@ -1097,7 +1199,7 @@ Tclmagic_Init(interp)
     /* Remember the interpreter */
     magicinterp = interp;
 
-    if (Tcl_InitStubs(interp, "8.1", 0) == NULL) return TCL_ERROR;
+    if (Tcl_InitStubs(interp, "8.5", 0) == NULL) return TCL_ERROR;
 
     /* Initialization and Startup commands */
     Tcl_CreateCommand(interp, "magic::initialize", (Tcl_CmdProc *)_magic_initialize,
@@ -1111,16 +1213,26 @@ Tclmagic_Init(interp)
     Tcl_CreateCommand(interp, "magic::tag", (Tcl_CmdProc *)AddCommandTag,
 			(ClientData)NULL, (Tcl_CmdDeleteProc *) NULL);
 
+    /* Add "*flags" command for manipulating run-time flags */
+    Tcl_CreateObjCommand(interp, "magic::*flags", (Tcl_ObjCmdProc *)_magic_flags,
+			(ClientData)NULL, (Tcl_CmdDeleteProc *) NULL);
+
     /* Add the magic TCL directory to the Tcl library search path */
 
     Tcl_Eval(interp, "lappend auto_path " TCL_DIR );
 
-    /* Set $CAD_ROOT as a Tcl variable */
+    /* Get $CAD_ROOT from a Tcl variable, if it exists, and if not, then */
+    /* set CAD_ROOT from the environment variable of the same name, if	 */
+    /* it exists, and finally fall back on the CAD_DIR set at compile	 */
+    /* time.								 */
 
-    cadroot = getenv("CAD_ROOT");
-    if (cadroot == NULL) cadroot = CAD_DIR;
-
-    Tcl_SetVar(interp, "CAD_ROOT", cadroot, TCL_GLOBAL_ONLY);
+    cadroot = Tcl_GetVar(interp, "CAD_ROOT", TCL_GLOBAL_ONLY);
+    if (cadroot == NULL)
+    {
+	cadroot = (const char *)getenv("CAD_ROOT");
+	if (cadroot == NULL) cadroot = CAD_DIR;
+	Tcl_SetVar(interp, "CAD_ROOT", cadroot, TCL_GLOBAL_ONLY);
+    }
 
     Tcl_PkgProvide(interp, "Tclmagic", MAGIC_VERSION);
     return TCL_OK;
@@ -1133,7 +1245,7 @@ Tclmagic_Init(interp)
 
 int
 Tclmagic_SafeInit(interp)
-    Tcl_Interp *interp; 
+    Tcl_Interp *interp;
 {
     return Tclmagic_Init(interp);
 }
