@@ -8,7 +8,7 @@
  *	Windows near the front of the list are on top of windows further
  *	towards the tail of the list.  Each window has some information
  *	about what is in the window, as well as the size of the window
- *	(both unclipped and clipped to accomodate windows that overlay it).
+ *	(both unclipped and clipped to accommodate windows that overlay it).
  *	Transforms control what portion of the window's contents show up
  *	on the screen, and at what magnification.
  *
@@ -30,25 +30,26 @@
  *	screen background color) is ignored by us.
  *
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/windows/windMain.c,v 1.1.1.1 2005/05/09 23:29:24 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header$";
 #endif  /* not lint */
 
 #include <stdio.h>
 #include <string.h>
+#include <ctype.h>	/* for isalnum() */
 
 #include "utils/magic.h"
 #include "utils/geometry.h"
@@ -73,20 +74,20 @@ int WindPackageType = WIND_MAGIC_WINDOWS;
 int WindScrollBarWidth = 7;
 
 /* ------ Internal variables that are global within the window package ----- */
-clientRec *windFirstClientRec = NULL;	/* the head of the linked list 
-					 * of clients 
+clientRec *windFirstClientRec = NULL;	/* the head of the linked list
+					 * of clients
 					 */
 MagWindow *windTopWindow = NULL;		/* the topmost window */
 MagWindow *windBottomWindow = NULL;	/* ...and the bottom window */
 extern Plane *windRedisplayArea;	/* See windDisplay.c for details. */
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * WindInit --
  *
  *	Initialize the window package.  No windows are created, but the
- *	package will be initialized so that it can do these things in the 
+ *	package will be initialized so that it can do these things in the
  *	future.
  *
  * Results:
@@ -101,7 +102,6 @@ void
 WindInit()
 {
     extern Stack *windGrabberStack;
-    extern GrGlyphs *windGlyphs;
     Rect ts;
     char glyphName[30];
 
@@ -117,7 +117,7 @@ WindInit()
     WindAreaChanged((MagWindow *) NULL, (Rect *) NULL);
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * WindAddClient --
@@ -127,7 +127,7 @@ WindInit()
  *
  * Results:
  *	A unique ID (of type WindClient) is returned.
- *	This is used to identify the client in future calls to the window 
+ *	This is used to identify the client in future calls to the window
  *	package.
  *
  * Routines supplied:
@@ -174,12 +174,12 @@ WindInit()
  *
  *
  *	( The window is about to be moved or resized.  This procedure will
- *	  be called twice.  
+ *	  be called twice.
  *
- *	  The first time (with 'final' == FALSE), the window 
- *	  will be passed in 'w' as it is now and a suggested new w_screenarea 
+ *	  The first time (with 'final' == FALSE), the window
+ *	  will be passed in 'w' as it is now and a suggested new w_screenarea
  *	  is passed in 'newpos'.  The client is free to modify 'newpos' to
- *	  be whatever screen location it desires.  The routine should not 
+ *	  be whatever screen location it desires.  The routine should not
  *	  pass 'w' to any window procedure such as windMove since 'w' has
  *	  the old transform, etc. instead of the new one.
  *
@@ -218,7 +218,7 @@ WindInit()
  */
 
 WindClient
-WindAddClient(clientName, create, delete, redisplay, command, update, 
+WindAddClient(clientName, create, delete, redisplay, command, update,
 		exitproc, reposition, icon)
     char *clientName;		/* A textual name for the client.  This
 				 * name will be visable in the user
@@ -267,7 +267,7 @@ WindAddClient(clientName, create, delete, redisplay, command, update,
     return (WindClient) res;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * WindGetClient --
@@ -295,7 +295,7 @@ WindGetClient(clientName, exact)
 
     if (exact)
     {
-	for (cr = windFirstClientRec; cr != (clientRec *) NULL; 
+	for (cr = windFirstClientRec; cr != (clientRec *) NULL;
 		cr = cr->w_nextClient)
 	    if (!strcmp(clientName, cr->w_clientName))
 		return (WindClient)cr;
@@ -306,7 +306,7 @@ WindGetClient(clientName, exact)
 
     found = NULL;
     length = strlen(clientName);
-    for (cr = windFirstClientRec; cr != (clientRec *) NULL; 
+    for (cr = windFirstClientRec; cr != (clientRec *) NULL;
 	    cr = cr->w_nextClient)
     {
 	if (!strncmp(clientName, cr->w_clientName, length))
@@ -371,7 +371,7 @@ WindPrintClientList(wizard)
 {
     clientRec *cr;
 
-    for (cr = windFirstClientRec; cr != (clientRec *) NULL; 
+    for (cr = windFirstClientRec; cr != (clientRec *) NULL;
 	    cr = cr->w_nextClient) {
 	if (wizard || (cr->w_clientName[0] != '*'))
 	    TxError("	%s\n", cr->w_clientName);
@@ -466,7 +466,7 @@ WindAddCommand(rc, text, func, dynamic)
     /* Copy the old values, inserting the new command in alphabetical	*/
     /* order.								*/
 
-    for (cidx = 0; (commandTable[cidx] != NULL) && 
+    for (cidx = 0; (commandTable[cidx] != NULL) &&
 		(strcmp(commandTable[cidx], text) < 0); cidx++)
     {
 	newcmdTable[cidx] = commandTable[cidx];
@@ -550,7 +550,7 @@ WindReplaceCommand(rc, command, newfunc)
 /*
  * ----------------------------------------------------------------------------
  * WindGetCommandTable --
- * 
+ *
  *	For functions wishing to parse the command table of a client
  *	directly, this routine returns a pointer to the top of the
  *	table.  The only purpose of this routine is to export the
